summaryrefslogtreecommitdiff
path: root/host/lib/include/host_misc.h
diff options
context:
space:
mode:
Diffstat (limited to 'host/lib/include/host_misc.h')
-rw-r--r--host/lib/include/host_misc.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/host/lib/include/host_misc.h b/host/lib/include/host_misc.h
index 6dc225c1..1bcf6f06 100644
--- a/host/lib/include/host_misc.h
+++ b/host/lib/include/host_misc.h
@@ -66,7 +66,7 @@ int vb2_read_file(const char *filename, uint8_t **data_ptr, uint32_t *size_ptr);
int vb2_write_file(const char *filename, const void *buf, uint32_t size);
/**
* Write a buffer which starts with a standard vb2_struct_common header.
*
* Determines the buffer size from the common header total size field.
*
@@ -74,7 +74,7 @@ int vb2_write_file(const char *filename, const void *buf, uint32_t size);
* @param buf Buffer to write
* @return VB2_SUCCESS, or non-zero if error.
*/
-int vb2_write_object(const char *filename, const void *buf);
+int vb21_write_object(const char *filename, const void *buf);
/**
* Round up a size to a multiple of 32 bits (4 bytes).
@@ -66,7 +66,7 @@ int vb2_read_file(const char *filename, uint8_t **data_ptr, uint32_t *size_ptr);
int vb2_write_file(const char *filename, const void *buf, uint32_t size);
/**
- * Write a buffer which starts with a standard vb2_struct_common header.
+ * Write a buffer which starts with a standard vb21_struct_common header.
*
* Determines the buffer size from the common header total size field.